from django.db import models
from django.utils.translation import gettext_lazy as _

class MessageTemplate(models.Model):
    """Model for storing reusable message templates."""
    
    title = models.CharField(
        _('Title'),
        max_length=200,
        help_text=_('Template title/name for easy identification')
    )
    
    description = models.TextField(
        _('Description'),
        blank=True,
        help_text=_('Optional description of what this template is used for')
    )
    
    content = models.TextField(
        _('Content'),
        help_text=_('The HTML content of the template')
    )
    
    category = models.CharField(
        _('Category'),
        max_length=100,
        blank=True,
        help_text=_('Optional category for organizing templates')
    )

    channels = models.ManyToManyField(
        'Channel',
        verbose_name=_('Channels'),
        blank=True,
        help_text=_('Channels where this template can be used')
    )
    
    created_at = models.DateTimeField(
        _('Created at'),
        auto_now_add=True
    )
    
    updated_at = models.DateTimeField(
        _('Updated at'),
        auto_now=True
    )

    class Meta:
        verbose_name = _('Message Template')
        verbose_name_plural = _('Message Templates')
        ordering = ['category', 'title']

    def __str__(self):
        return self.title 


from django.http import JsonResponse
from django.views.generic import View
from django.utils.decorators import method_decorator
from django.contrib.auth.decorators import login_required
from django.db.models import Q

from ..models import MessageTemplate, Channel

"""
This view is an API endpoint used to serve message templates to TinyMCE.
It allows for filtering templates by channel.
"""

@method_decorator(login_required, name='dispatch')
class MessageTemplateListView(View):
    """View to serve message templates to TinyMCE."""
    
    def get(self, request, *args, **kwargs):
        # Get channel_id from query params if provided
        channel_id = request.GET.get('channel_id')
        
        # Base queryset
        templates = MessageTemplate.objects.all()
        
        # Filter by channel if specified
        if channel_id:
            try:
                channel = Channel.objects.get(id=channel_id)
                templates = templates.filter(Q(channels=channel) | Q(channels__isnull=True))
            except Channel.DoesNotExist:
                templates = templates.filter(channels__isnull=True)
        
        # Convert to TinyMCE template format
        tinymce_templates = []
        for template in templates:
            tinymce_templates.append({
                'title': template.title,
                'description': template.description,
                'content': template.content,
            })
        
        return JsonResponse(tinymce_templates, safe=False) 